@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11919 2020-02-12 07:39:14Z Lavender $
+# $Id: __init__.py 11894 2020-02-04 12:08:11Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-02-12 16:39:14 +0900 (週三, 12 二月 2020) $
-# $Revision: 11919 $
+# $Date: 2020-02-04 20:08:11 +0800 (週二, 04 二月 2020) $
+# $Revision: 11894 $
 
 import os
 import sys
@@ -337,13 +337,6 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
 
     #=========================================================================
-    # payment
-    defaultSettings = {
-        'SESSION_COOKIE_SAMESITE' : None,
-    }
-
-    update(settingsDict, defaultSettings)
-    
     ecpayEnable = False
     if 'IUNO_SHOP_ECPAY_ENABLE' in settingsDict:
         ecpayEnable = settingsDict['IUNO_SHOP_ECPAY_ENABLE']
@@ -374,10 +367,6 @@ def attachSettings(settingsDict, enablePaypal=False):
            
         ]
     }
-    
-    def accessFunction(user, urlName, urlArgs, urlKwargs):
-        return user.is_staff
-
 
     if enablePaypal:
         require('PAYPAL_API_USERNAME', settingsDict)
@@ -399,37 +388,43 @@ def attachSettings(settingsDict, enablePaypal=False):
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('Paypal transactions'),
             'url_name': 'paypal-express-list',
-            'access_fn': accessFunction,
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
         })
-        
+
     if ecpayEnable:
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('ECPay transactions'),
             'url_name': 'ecpayTransaction',
-            'access_fn': accessFunction,
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
         })
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('ECPay logistic transactions'),
             'url_name': 'ecpayLogisticTransaction',
-            'access_fn': accessFunction,
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
         })
     if allpayEnable:
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('AllPay transactions'),
             'url_name': 'allpayTransaction',
-            'access_fn': accessFunction,
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
         })
     if spgatewayEnable:
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('Spgateway transactions'),
             'url_name': 'spgatewayTransaction',
-            'access_fn': accessFunction,
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
         })
     if cathaybkEnable:
         ADDING_OSCAR_DASHBOARD_NAVIGATION['children'].append({
             'label': _('Cathay credit transactions'),
             'url_name': 'cathaybkCreditTransaction',
-            'access_fn': accessFunction,
+            'access_fn': \
+                lambda user, url_name, url_args, url_kwargs: user.is_staff,
         })
 
     if enablePaypal or ecpayEnable or allpayEnable or spgatewayEnable:
@@ -450,7 +445,8 @@ def attachSettings(settingsDict, enablePaypal=False):
             s['children'].append({
                 'label': _('Bonus settings'),
                 'url_name': 'bonusSettings',
-                'access_fn': accessFunction,
+                'access_fn': \
+                    lambda user, url_name, url_args, url_kwargs: user.is_staff,
             })
     #=========================================================================
     
