@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11890 2020-02-02 14:49:15Z Trista $
+# $Id: forms.py 11907 2020-02-06 03:48:51Z Trista $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $ (last)
-# $Date: 2020-02-02 23:49:15 +0900 (週日, 02 二月 2020) $
-# $Revision: 11890 $
+# $Date: 2020-02-06 11:48:51 +0800 (週四, 06 二月 2020) $
+# $Revision: 11907 $
 
 import os
 import re
@@ -190,41 +190,24 @@ def apply_search2(self, queryset):
     Order = get_model('order', 'Order')
     from django.db.models import Sum
     
-    if data['expenseFrom'] and data['expenseTo']:
+    if data['expenseFrom'] or data['expenseTo']:
+        parameters = {
+            'expense__lte': data['expenseTo'], 
+            'expense__gte': data['expenseFrom']
+        }
+        filteredParameter = {
+            k: v for k, v in parameters.items() if v is not None
+        }
         userIdList = Order.objects.values('user_id').order_by(
                 'user_id'
             ).annotate(
                 expense=Sum('total_incl_tax')
             ).filter(
-                expense__lte=data['expenseTo'], 
-                expense__gte=data['expenseFrom']
+                **filteredParameter
             ).values_list('user_id')
         queryset = queryset.filter(id__in=userIdList)
         
            
-    elif data['expenseFrom']:
-        userIdList = Order.objects.values('user_id').order_by(
-                'user_id'
-            ).annotate(
-                expense=Sum('total_incl_tax')
-            ).filter(
-                expense__gte=data['expenseFrom']
-            ).values_list('user_id')
-        queryset = queryset.filter(id__in=userIdList)
-                
-    elif data['expenseTo']:
-        userIdList = Order.objects.values('user_id').order_by(
-                'user_id'
-            ).annotate(
-                expense=Sum('total_incl_tax')
-            ).filter(
-                expense__lte=data['expenseTo'], 
-            ).values_list('user_id')
-            
-        queryset = queryset.filter(id__in=userIdList)
-            
-           
-        
     
     return queryset
 
